pub struct Transaction {
pub date: NaiveDate,
pub amount: Decimal,
pub payee: Option<String>,
pub transaction_type: String,
pub fitid: Option<String>,
pub status: Option<String>,
pub memo: Option<String>,
}Fields
date: NaiveDateamount: Decimalpayee: Option<String>transaction_type: Stringfitid: Option<String>status: Option<String>memo: Option<String>Trait Implementations
Sourceimpl Clone for Transaction
impl Clone for Transaction
Sourcefn clone(&self) -> Transaction
fn clone(&self) -> Transaction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transaction
impl Debug for Transaction
Sourceimpl<'de> Deserialize<'de> for Transaction
impl<'de> Deserialize<'de> for Transaction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for Transaction
impl Serialize for Transaction
Sourceimpl TryFrom<ParsedTransaction> for Transaction
impl TryFrom<ParsedTransaction> for Transaction
Sourcetype Error = StatementParseError
type Error = StatementParseError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<QfxTransaction> for Transaction
impl TryFrom<QfxTransaction> for Transaction
Sourcetype Error = StatementParseError
type Error = StatementParseError
The type returned in the event of a conversion error.